/* ISC license. */

/* MT-unsafe */

#include <skalibs/textmessage.h>

textmessage_sender textmessage_sender_x_ = TEXTMESSAGE_SENDER_ZERO ;
